#!/usr/bin/env node
/***
 * 模版验证
 *  使用： feflow verify -s <source-template-path> -d <destination-project-path>
 *  注意：如果省略 -s 参数，则从当前路径进行验证
 * @author jiakaiguang
 * @time 2018-05-11
 */
const program = require('commander')
const path = require('path')
const exists = require('fs').existsSync
const inquirer = require('inquirer')
const chalk = require('chalk')

const logger = require('../lib/logger')
const generate = require('../lib/generate')

/**
 * Usage
 */
program
  // .usage('[project-name]')
  .option('-s, --src', 'source template directory') // 源模版路径
  .option('-d, --dist', 'destination project directory') // 工程存放路径

/**
 * Help
 */
program.on('--help', () => {
  console.log('  Examples:')
  console.log()
  console.log(chalk.gray('  # verify a template'))
  console.log('  $ feflow verify -d /Users/fedor/Downloads/verify')
  console.log()
})

program.parse(process.argv)
if (program.args.length < 1) {
  return program.help()
}

const src = program.src // 源模版路径
const dist = program.dist // 工程存放路径

if(!dist) {
  return logger.fatal('must use -d option for destination path')
}

let templatePath
if(src) {
  templatePath = program.args[0]
} else {
  templatePath = process.cwd()
}

const destPath = program.args[program.args.length-1]
const projectName = path.basename(templatePath)

console.log()
process.on('exit', () => {
  console.log()
})

if (exists(path.resolve(destPath, projectName))) {
  inquirer.prompt([{
    type: 'confirm',
    message: 'Destination directory exists. Continue?',
    name: 'ok'
  }]).then(answers => {
    if (answers.ok) {
      run()
    }
  }).catch(logger.fatal)
} else {
  run()
}

async function run() {
  try {
    await generate(templatePath, destPath)
    console.log()
    logger.success('generated project "%s".', projectName)
  } catch (err) {
    logger.fatal(err)
  }
}
