const shell = require('shelljs')
const fs = require('fs')
const path = require('path')

const treeKill = require('tree-kill');
const Spawn = require('./spawn')

/**
 * get templates
 */
exports.getTemplates = () => {
  const templatePath = path.join(__dirname, '/template')
  const templateNames = fs.readdirSync(templatePath)

  let templates = []
  for (let template of templateNames) {
    const pkg = require(`./template/${template}/package.json`)
    templates.push({
      template,
      name: pkg.name,
      description: pkg.description
    })
  }
  return templates
}

/**
 * generate project
 */
exports.generate = (templateName, projectName, projectPostion) => {

  // detect project path
  const projectPath = `${projectPostion}/${projectName}`
  if (fs.existsSync(projectPath)) {
    return {
      status: 0,
      message: `! project name already existed :( `
    }
  }

  // mkdir project path
  shell.mkdir('-p', projectPath)

  // copy template to project path
  shell.cp('-R', path.join(__dirname, `template/${templateName}`) + '/*', projectPath)
  shell.cp('-R', path.join(__dirname, `template/${templateName}`) + '/.*', projectPath)

  return {
    status: 1,
    message: `√ generate project succeed :) `
  }
}

// function runCommand(command, position, name) {
//   shell.cd(`${position}/${name}`)
//   shell.config.execPath = shell.which('node');
//   if (shell.exec(command).code !== 0) {
//     shell.echo(`Error: ${command} failed.`)
//     return shell.exit(1)
//   }
//   return true
// }

/**
 * exec script
 */
exports.exec = (script, projectPath) => {
  return new Spawn(`cd ${projectPath} && npm run ${script}`)
  // return runCommand('npm run dev', position, name)
}

/**
 * kill progress
 */
exports.kill = (pid) => {
  treeKill(pid);
}
